@@ -27,6 +27,7 @@ enum action {
 	SEL_MEDIA,
 	SEL_FMEDIA,
 	SEL_DFB,
+	SEL_ARCHIVE,
 	SEL_LIST,
 	SEL_EXTRACT,
 	SEL_FSIZE,
@@ -42,7 +43,11 @@ enum action {
 	SEL_RENAMEALL,
 	SEL_HELP,
 	SEL_RUN,
+	SEL_RUNSCRIPT,
 	SEL_RUNARG,
+#ifdef __linux__
+	SEL_LOCK,
+#endif
 	SEL_CDQUIT,
 	SEL_QUIT,
 };
@@ -62,7 +67,7 @@ struct assoc {
 };
 
 static struct assoc assocs[] = {
-	{ "\\.(c|cpp|h|log|md|py|sh|txt)$", "text" },
+	{ "\\.(c|cpp|h|log|md|py|rb|sh|txt)$", "text" },
 };
 
 static struct key bindings[] = {
@@ -118,6 +123,7 @@ static struct key bindings[] = {
 	{ '/',            SEL_FLTR,      "",     "" },
 	/* Toggle filter mode */
 	{ KEY_IC,         SEL_MFLTR,     "",     "" },
+	{ CONTROL('I'),   SEL_MFLTR,     "",     "" },
 	/* Desktop search */
 	{ CONTROL('_'),   SEL_SEARCH,    "",     "" },
 	/* Toggle hide .dot files */
@@ -132,10 +138,12 @@ static struct key bindings[] = {
 	{ 'M',            SEL_FMEDIA,    "-f",   "" },
 	/* Open dir in desktop file manager */
 	{ 'o',            SEL_DFB,       "",     "" },
+	/* Create archive */
+	{ 'f',            SEL_ARCHIVE,   "",     "" },
 	/* List archive */
-	{ 'F',            SEL_LIST,      "-l", "" },
+	{ 'F',            SEL_LIST,      "-l",   "" },
 	/* Extract archive */
-	{ CONTROL('F'),   SEL_EXTRACT,   "-x", "" },
+	{ CONTROL('F'),   SEL_EXTRACT,   "-x",   "" },
 	/* Toggle sort by size */
 	{ 's',            SEL_FSIZE,     "",     "" },
 	/* Sort by total block count including dir contents */
@@ -148,6 +156,7 @@ static struct key bindings[] = {
 	{ KEY_F(5),       SEL_REDRAW,    "",     "" }, /* Undocumented */
 	/* Copy currently selected file path */
 	{ CONTROL('K'),   SEL_COPY,      "",     "" },
+	{ ' ',            SEL_COPY,      "",     "" },
 	/* Toggle copy multiple file paths */
 	{ CONTROL('Y'),   SEL_COPYMUL,   "",     "" },
 	/* Toggle quote on while copy */
@@ -160,14 +169,21 @@ static struct key bindings[] = {
 	{ CONTROL('R'),   SEL_RENAME,    "",     "" },
 	{ KEY_F(2),       SEL_RENAME,    "",     "" }, /* Undocumented */
 	/* Rename contents of current dir */
-	{ 'R',            SEL_RENAMEALL, "",     "" },
+	{ 'r',            SEL_RENAMEALL, "",     "" },
 	/* Show help */
 	{ '?',            SEL_HELP,      "",     "" },
 	/* Run command */
 	{ '!',            SEL_RUN,       "sh",   "SHELL" },
+	{ CONTROL(']'),   SEL_RUN,       "sh",   "SHELL" },
+	/* Run a custom script */
+	{ 'R',            SEL_RUNSCRIPT, "sh",   "SHELL" },
 	/* Run command with argument */
-	{ 'e',            SEL_RUNARG,    "vi",   "EDITOR" },
+	{ 'e',            SEL_RUNARG,    "",     "VISUAL" },
 	{ 'p',            SEL_RUNARG,    "less", "PAGER" },
+#ifdef __linux__
+	/* Lock screen */
+	{ 'L',            SEL_LOCK,      "",     "" },
+#endif
 	/* Change dir on quit */
 	{ 'Q',            SEL_CDQUIT,    "",     "" },
 	{ CONTROL('G'),   SEL_CDQUIT,    "",     "" },
